==> igniteui-react-16.16.2.tgz: package/esm5/lib/igr-pane-header-connection-event-args.js <==
import { PaneHeaderConnectionEventArgs as PaneHeaderConnectionEventArgs_internal } from "./PaneHeaderConnectionEventArgs";
var IgrPaneHeaderConnectionEventArgs = /** @class */ /*@__PURE__*/ (function () {
    function IgrPaneHeaderConnectionEventArgs() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    IgrPaneHeaderConnectionEventArgs.prototype.createImplementation = function () {
        return new PaneHeaderConnectionEventArgs_internal();
    };
    Object.defineProperty(IgrPaneHeaderConnectionEventArgs.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrPaneHeaderConnectionEventArgs.prototype.onImplementationCreated = function () {
    };
    IgrPaneHeaderConnectionEventArgs.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    };
    Object.defineProperty(IgrPaneHeaderConnectionEventArgs.prototype, "detail", {
        get: function () {
            if (this.i.a == null) {
                return null;
            }
            if (!this.i.a.externalObject) {
                var e = new IgrPaneHeaderConnectionEventArgs();
                e._implementation = this.i.a;
                this.i.a.externalObject = e;
            }
            return this.i.a.externalObject;
        },
        set: function (v) {
            v == null ? this.i.a = null : this.i.a = v.i;
        },
        enumerable: false,
        configurable: true
    });
    return IgrPaneHeaderConnectionEventArgs;
}());
export { IgrPaneHeaderConnectionEventArgs };

==> igniteui-react-18.5.1.tgz: package/esm5/lib/igr-pane-header-connection-event-args.js <==
import { IgrPaneHeaderConnectionEventArgsDetail } from "./igr-pane-header-connection-event-args-detail";
import { PaneHeaderConnectionEventArgs as PaneHeaderConnectionEventArgs_internal } from "./PaneHeaderConnectionEventArgs";
var IgrPaneHeaderConnectionEventArgs = /** @class */ /*@__PURE__*/ (function () {
    function IgrPaneHeaderConnectionEventArgs() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    }
    IgrPaneHeaderConnectionEventArgs.prototype.createImplementation = function () {
        return new PaneHeaderConnectionEventArgs_internal();
    };
    Object.defineProperty(IgrPaneHeaderConnectionEventArgs.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrPaneHeaderConnectionEventArgs.prototype.onImplementationCreated = function () {
    };
    IgrPaneHeaderConnectionEventArgs.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    };
    Object.defineProperty(IgrPaneHeaderConnectionEventArgs.prototype, "detail", {
        get: function () {
            var r = this.i.b;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = new IgrPaneHeaderConnectionEventArgsDetail();
                if (r.$type) {
                    e._implementation = r;
                }
                else {
                    if (e.i.setNativeElement) {
                        e.i.setNativeElement(r);
                    }
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            v == null ? this.i.b = null : this.i.b = v.i;
        },
        enumerable: false,
        configurable: true
    });
    return IgrPaneHeaderConnectionEventArgs;
}());
export { IgrPaneHeaderConnectionEventArgs };
